@@ -5,16 +5,17 @@ use warnings;
 use Getopt::Long 'GetOptions';
 use Exporter ();
 
-our $VERSION = '0.004';
+our $VERSION = '1.000';
 
 our @ISA = 'Exporter';
 our @EXPORT = 'GetOptions';
 
-my @config = qw(default gnu_getopt no_auto_abbrev no_ignore_case);
+my @config = qw(default gnu_getopt no_ignore_case);
 
 sub import {
 	my $class = shift;
-	$class->export_to_level(1, $class, 'GetOptions');
+	$class->export_to_level(1);
+	shift if @_ and $_[0] eq ':config';
 	Getopt::Long::Configure(@config, @_);
 }
 
@@ -46,6 +47,9 @@ L<Getopt::Long> configuration may be passed as import parameters.
  use Getopt::Long::Modern qw(auto_help auto_version pass_through);
 
 For any more advanced usage, you should probably use L<Getopt::Long> directly.
+The equivalent L<Getopt::Long> configuration to using this module is:
+
+ use Getopt::Long qw(:config gnu_getopt no_ignore_case);
 
 =head1 DEFAULTS
 
@@ -60,15 +64,6 @@ C<bundling> to allow short options to be bundled together, C<permute> to allow
 specifying options before or after other arguments, and C<no_getopt_compat> to
 disallow C<+> for specifying options.
 
-=head2 no_auto_abbrev
-
-This disables the functionality that automatically allows abbreviated versions
-of any option, because no one is ever going to specify C<--foo> as C<--fo>, and
-it is not useful when you have multiple options that abbreviate to the same
-single-letter option. When it is desired to have a single-letter short option
-versions available, this can be specified explicitly with the normal C<|>
-syntax.
-
 =head2 no_ignore_case
 
 This makes all options case-sensitive, which is expected and required when
